Clazz.declarePackage("J.rendersurface");
Clazz.load(["J.rendersurface.MolecularOrbitalRenderer"], "J.rendersurface.NBORenderer", null, function(){
var c$ = Clazz.declareType(J.rendersurface, "NBORenderer", J.rendersurface.MolecularOrbitalRenderer);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
